==> shoelace_messages-1.0.0.tar.gz: shoelace_messages/src/EventSubscriber/MessagesEventSubscriber.php <==
<?php

namespace Drupal\shoelace_messages\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\KernelEvents;
use Drupal\Core\Ajax\AjaxResponse;
use Symfony\Component\HttpKernel\Event\FilterResponseEvent;
use Drupal\shoelace_messages\Ajax\ShoelaceMessagesCommand;

/**
 * Event Subscriber MessagesEventSubscriber.
 */
class MessagesEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {

    return [
      KernelEvents::RESPONSE => [['onKernelResponse', 500]]
    ];

  }

  /**
   * Handles the onKernelResponse event and adds the shoelace messages on the page.
   *
   * @param \Symfony\Component\HttpKernel\Event\FilterResponseEvent $event
   *   The response event.
   */
  public function onKernelResponse(FilterResponseEvent $event) {
    $response = $event->getResponse();

    // only for AJAX responses.
    if (!$response instanceof AjaxResponse) {
      // this is not an ajax request therefore cancel this operation
      return;
    }

    // using private temp store to get the status messages provided by the mymodule_preprocess_status_messages
    $tempstore = \Drupal::service('tempstore.private')->get('shoelace_messages');

    // array of messages
    $messages = $tempstore->get('messages_array');

    // have we set messages to be displayed?
    if (isset($messages) && !empty($messages)) {

      // yes we have messages, so let's call the javascript command function to display them
      $response->addCommand(
        new ShoelaceMessagesCommand($messages)
      );

      // delete tempstore variable
      $tempstore->delete('messages_array');

    }

    // Let's do this...
    $event->setResponse($response);
  }

}

==> shoelace_messages-1.0.1.tar.gz: shoelace_messages/src/EventSubscriber/MessagesEventSubscriber.php <==
<?php

namespace Drupal\shoelace_messages\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\KernelEvents;
use Drupal\Core\Ajax\AjaxResponse;
use Symfony\Component\HttpKernel\Event\FilterResponseEvent;
use Drupal\shoelace_messages\Ajax\ShoelaceMessagesCommand;

/**
 * Event Subscriber MessagesEventSubscriber.
 */
class MessagesEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {

    return [
      KernelEvents::RESPONSE => [['onKernelResponse']]
    ];

  }

  /**
   * Handles the onKernelResponse event and adds the shoelace messages on the page.
   *
   * @param \Symfony\Component\HttpKernel\Event\FilterResponseEvent $event
   *   The response event.
   */
  public function onKernelResponse(FilterResponseEvent $event) {
    $response = $event->getResponse();

    // using private temp store to get the status messages provided by the mymodule_preprocess_status_messages
    $tempstore = \Drupal::service('tempstore.private')->get('shoelace_messages');

    // only for AJAX responses. Cancel if not ajax
    if (!$response instanceof AjaxResponse) {
      // delete tempstore variable
      $tempstore->delete('messages_array');
      return;
    }

    // array of messages
    $messages = $tempstore->get('messages_array');

    // have we set messages to be displayed?
    if (isset($messages) && !empty($messages)) {

      // yes we have messages, so let's call the javascript command function to display them
      $response->addCommand(
        new ShoelaceMessagesCommand($messages)
      );

      // delete tempstore variable
      $tempstore->delete('messages_array');

    }

    // Let's do this...
    $event->setResponse($response);
  }

}
